//
//  PhotoBrowserTableViewController.m
//  PhotoThing
//
//  Created by Maneesh Goel on 8/24/12.
//  Copyright (c) 2012 Maneesh Goel. All rights reserved.
//

#import "PhotoBrowserTableViewController.h"
#import "ParseStore.h"
#import <Parse/Parse.h>
#import <MobileCoreServices/MobileCoreServices.h>
#import "PhotoViewController.h"

@interface PhotoBrowserTableViewController ()
@property (strong) NSArray *cells;
@property (strong) NSArray *photos;
@end

@implementation PhotoBrowserTableViewController
-(id)initWithStyle:(UITableViewStyle)style {
    self = [super initWithStyle:style];
    if (self) {
        self.cells = [NSArray new];
        self.tableView.rowHeight = 176;
    }
    return self;
}
-(void)viewWillAppear:(BOOL)animated
{
    self.cells = [ParseStore getCellImages];
    
}

- (void)viewDidLoad
{
    [super viewDidLoad];
    UIBarButtonItem *takePhotoButton = [[UIBarButtonItem alloc] initWithTitle:@"Take Photo!" style:UIBarButtonItemStylePlain target:self action:@selector(takePhoto)];
    self.toolbarItems = [NSArray arrayWithObject:takePhotoButton];
}

-(void)viewDidAppear:(BOOL)animated
{
    // go pick up actual files
    self.photos = [ParseStore getPhotos];

}

-(void)takePhoto {
    UIImagePickerController *imagePicker = [UIImagePickerController new];
    imagePicker.sourceType = UIImagePickerControllerSourceTypePhotoLibrary;
    imagePicker.mediaTypes = [NSArray arrayWithObject:(NSString *)kUTTypeImage];
    imagePicker.delegate = self;
    [self presentModalViewController:imagePicker animated:YES];
}

-(void)imagePickerController:(UIImagePickerController *)picker didFinishPickingMediaWithInfo:(NSDictionary *)info {
    [ParseStore submitPhoto:[info objectForKey:UIImagePickerControllerOriginalImage]];
    [self.tableView reloadData];
    [self dismissModalViewControllerAnimated:YES];
}

- (void)viewDidUnload
{
    [super viewDidUnload];
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    return (interfaceOrientation == UIInterfaceOrientationPortrait);
}

#pragma mark - Table view data source

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
    return 1;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return [self.cells count];
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    //static NSString *CellIdentifier = @"Cell";
    //UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier];
    UITableViewCell *cell = [[UITableViewCell alloc] initWithStyle:UITableViewCellStyleDefault reuseIdentifier:nil];
    PFFile* file = [[self.cells objectAtIndex:indexPath.row] objectForKey:@"cellImage"];
    UIImage* img = [UIImage imageWithData:[file getData]];
    cell.imageView.image = img;
    
    return cell;
}

/*
// Override to support conditional editing of the table view.
- (BOOL)tableView:(UITableView *)tableView canEditRowAtIndexPath:(NSIndexPath *)indexPath
{
    // Return NO if you do not want the specified item to be editable.
    return YES;
}
*/

/*
// Override to support editing the table view.
- (void)tableView:(UITableView *)tableView commitEditingStyle:(UITableViewCellEditingStyle)editingStyle forRowAtIndexPath:(NSIndexPath *)indexPath
{
    if (editingStyle == UITableViewCellEditingStyleDelete) {
        // Delete the row from the data source
        [tableView deleteRowsAtIndexPaths:@[indexPath] withRowAnimation:UITableViewRowAnimationFade];
    }   
    else if (editingStyle == UITableViewCellEditingStyleInsert) {
        // Create a new instance of the appropriate class, insert it into the array, and add a new row to the table view
    }   
}
*/

/*
// Override to support rearranging the table view.
- (void)tableView:(UITableView *)tableView moveRowAtIndexPath:(NSIndexPath *)fromIndexPath toIndexPath:(NSIndexPath *)toIndexPath
{
}
*/

/*
// Override to support conditional rearranging of the table view.
- (BOOL)tableView:(UITableView *)tableView canMoveRowAtIndexPath:(NSIndexPath *)indexPath
{
    // Return NO if you do not want the item to be re-orderable.
    return YES;
}
*/

#pragma mark - Table view delegate

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    PhotoViewController *pvc = [[PhotoViewController alloc] init];
    PFQuery *query = [PFQuery queryWithClassName:@"Photo"];
    NSString *photoID = [[self.cells objectAtIndex:indexPath.row] objectForKey:@"cellPhotoID"];
    NSLog(@"photo id is %@", photoID);
    [query whereKey:@"photoID" equalTo:photoID];
    PFFile *file = [[query getFirstObject] objectForKey:@"imageFile"];
    UIImage* img = [UIImage imageWithData:[file getData]];
    pvc.photo = img;
    [self.navigationController pushViewController:pvc animated:YES];
}

@end
